/***********************************************************************************************************************************
Remote Command
***********************************************************************************************************************************/
#ifndef COMMAND_REMOTE_REMOTE_H
#define COMMAND_REMOTE_REMOTE_H

#include "protocol/server.h"

/***********************************************************************************************************************************
Functions
***********************************************************************************************************************************/
// Remote command
void cmdRemote(ProtocolServer *server);

#endif
